@@ -28,8 +28,7 @@ use {
             khr_surface as vks,
             khr_swapchain::KHR_SWAPCHAIN_EXTENSION_NAME,
         },
-        vk1_0, vk1_1, vk1_2, DeviceLoader, ExtendableFromConst as _, ExtendableFromMut as _,
-        LoaderError,
+        vk1_0, vk1_1, vk1_2, DeviceLoader, ExtendableFrom as _, LoaderError,
     },
     smallvec::SmallVec,
     std::{collections::HashMap, convert::TryInto as _, ffi::CStr, num::NonZeroU32, sync::Arc},
@@ -37,8 +36,8 @@ use {
 
 #[derive(Clone, Debug)]
 pub(crate) struct Properties {
-    pub(crate) extension: Vec<vk1_0::ExtensionProperties>,
-    pub(crate) family: Vec<vk1_0::QueueFamilyProperties>,
+    pub(crate) extension: SmallVec<[vk1_0::ExtensionProperties; 8]>,
+    pub(crate) family: SmallVec<[vk1_0::QueueFamilyProperties; 8]>,
     pub(crate) memory: vk1_0::PhysicalDeviceMemoryProperties,
 
     pub(crate) v10: vk1_0::PhysicalDeviceProperties,
@@ -170,22 +169,22 @@ unsafe fn collect_properties_and_features(
         family: family_properties,
         memory: memory_properties,
         v10: properties10,
-        v11: properties11.build(),
-        v12: properties12.build(),
-        edi: properties_edi.build(),
-        acc: properties_acc.build(),
-        rt: properties_rt.build(),
+        v11: properties11.build_dangling(),
+        v12: properties12.build_dangling(),
+        edi: properties_edi.build_dangling(),
+        acc: properties_acc.build_dangling(),
+        rt: properties_rt.build_dangling(),
     };
 
     let mut features = Features {
         v10: features10,
-        v11: features11.build(),
-        v12: features12.build(),
-        sbl: features_sbl.build(),
-        edi: features_edi.build(),
-        bda: features_bda.build(),
-        acc: features_acc.build(),
-        rt: features_rt.build(),
+        v11: features11.build_dangling(),
+        v12: features12.build_dangling(),
+        sbl: features_sbl.build_dangling(),
+        edi: features_edi.build_dangling(),
+        bda: features_bda.build_dangling(),
+        acc: features_acc.build_dangling(),
+        rt: features_rt.build_dangling(),
     };
 
     properties.v11.p_next = std::ptr::null_mut();
@@ -253,10 +252,8 @@ impl PhysicalDevice {
             if self.features.sbl.scalar_block_layout > 0 {
                 features.push(Feature::ScalarBlockLayout);
             }
-        } else if graphics.instance.enabled().vk1_2 {
-            if self.features.v12.scalar_block_layout > 0 {
-                features.push(Feature::ScalarBlockLayout);
-            }
+        } else if graphics.instance.enabled().vk1_2 && self.features.v12.scalar_block_layout > 0 {
+            features.push(Feature::ScalarBlockLayout);
         }
 
         if self
@@ -399,10 +396,8 @@ impl PhysicalDevice {
             if self.features.bda.buffer_device_address > 0 {
                 features.push(Feature::BufferDeviceAddress);
             }
-        } else if graphics.instance.enabled().vk1_2 {
-            if self.features.v12.buffer_device_address > 0 {
-                features.push(Feature::BufferDeviceAddress);
-            }
+        } else if graphics.instance.enabled().vk1_2 && self.features.v12.buffer_device_address > 0 {
+            features.push(Feature::BufferDeviceAddress);
         }
 
         if self
@@ -436,7 +431,12 @@ impl PhysicalDevice {
                 vk1_0::PhysicalDeviceType::INTEGRATED_GPU => Some(DeviceKind::Integrated),
                 vk1_0::PhysicalDeviceType::DISCRETE_GPU => Some(DeviceKind::Discrete),
                 vk1_0::PhysicalDeviceType::CPU => Some(DeviceKind::Software),
-                vk1_0::PhysicalDeviceType::OTHER | vk1_0::PhysicalDeviceType::VIRTUAL_GPU | _ => {
+                vk1_0::PhysicalDeviceType::OTHER | vk1_0::PhysicalDeviceType::VIRTUAL_GPU => None,
+                _ => {
+                    tracing::error!(
+                        "Unexpected device type value: {:?}",
+                        self.properties.v10.device_type
+                    );
                     None
                 }
             },
@@ -522,7 +522,7 @@ impl PhysicalDevice {
                 return Err(CreateDeviceError::BadFamiliesRequested);
             }
 
-            let priorities = families_requested.entry(family).or_insert(Vec::new());
+            let priorities = families_requested.entry(family).or_insert_with(Vec::new);
 
             if arith_gt(
                 priorities.len() + count,
@@ -1019,8 +1019,7 @@ impl PhysicalDevice {
 
         let instance = &self.graphics().instance;
 
-        let result =
-            unsafe { DeviceLoader::new(instance, self.physical, &device_create_info, None) };
+        let result = unsafe { DeviceLoader::new(instance, self.physical, &device_create_info) };
 
         let logical = match result {
             Err(LoaderError::SymbolNotAvailable) => {
@@ -1047,13 +1046,13 @@ impl PhysicalDevice {
             self.properties,
             Features {
                 v10: features2.features,
-                v11: features11.build(),
-                v12: features12.build(),
-                sbl: features_sbl.build(),
-                edi: features_edi.build(),
-                bda: features_bda.build(),
-                acc: features_acc.build(),
-                rt: features_rt.build(),
+                v11: features11.build_dangling(),
+                v12: features12.build_dangling(),
+                sbl: features_sbl.build_dangling(),
+                edi: features_edi.build_dangling(),
+                bda: features_bda.build_dangling(),
+                acc: features_acc.build_dangling(),
+                rt: features_rt.build_dangling(),
             },
             version,
             families.iter().flat_map(|&(family, count)| {
