@@ -88,6 +88,7 @@ impl Debug for Buffer {
     fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
         if fmt.alternate() {
             #[derive(Debug)]
+            #[allow(unused)]
             struct Memory {
                 handle: vk1_0::DeviceMemory,
                 offset: u64,
@@ -177,6 +178,7 @@ impl Debug for MappableBuffer {
     fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
         if fmt.alternate() {
             #[derive(Debug)]
+            #[allow(unused)]
             struct Memory {
                 handle: vk1_0::DeviceMemory,
                 offset: u64,
@@ -281,8 +283,8 @@ impl ImageFlavor {
 /// Images represent a one, two or three dimensional arrays of texel.
 #[derive(Clone)]
 pub struct Image {
-    info: ImageInfo,
     handle: vk1_0::Image,
+    info: ImageInfo,
     inner: Arc<ImageInner>,
 }
 
@@ -295,19 +297,17 @@ impl Drop for ImageInner {
     fn drop(&mut self) {
         resource_freed();
 
-        match &mut self.flavor {
-            ImageFlavor::DeviceImage {
-                memory_block,
-                index,
-            } => {
-                if let Some(device) = self.owner.upgrade() {
-                    unsafe {
-                        let block = ManuallyDrop::take(memory_block);
-                        device.destroy_image(*index, block);
-                    }
+        if let ImageFlavor::DeviceImage {
+            memory_block,
+            index,
+        } = &mut self.flavor
+        {
+            if let Some(device) = self.owner.upgrade() {
+                unsafe {
+                    let block = ManuallyDrop::take(memory_block);
+                    device.destroy_image(*index, block);
                 }
             }
-            _ => {}
         }
     }
 }
@@ -337,15 +337,13 @@ impl Debug for Image {
                 .field("owner", &self.inner.owner)
                 .field("handle", &self.handle);
 
-            match &self.inner.flavor {
-                ImageFlavor::DeviceImage {
-                    memory_block,
-                    index,
-                } => {
-                    fmt.field("memory_block", &**memory_block)
-                        .field("index", index);
-                }
-                _ => {}
+            if let ImageFlavor::DeviceImage {
+                memory_block,
+                index,
+            } = &self.inner.flavor
+            {
+                fmt.field("memory_block", &**memory_block)
+                    .field("index", index);
             }
 
             fmt.finish()
@@ -534,11 +532,8 @@ impl Drop for Fence {
         resource_freed();
 
         if let Some(device) = self.owner.upgrade() {
-            match self.state {
-                FenceState::Armed { .. } => {
-                    device.wait_fences(&mut [self], true);
-                }
-                _ => {}
+            if let FenceState::Armed { .. } = self.state {
+                device.wait_fences(&mut [self], true);
             }
             unsafe { device.destroy_fence(self.index) }
         }
@@ -1207,7 +1202,7 @@ impl Drop for DescriptorSetInner {
 
         if let Some(device) = self.owner.upgrade() {
             unsafe { device.destroy_descriptor_set(ManuallyDrop::take(&mut self.set)) }
-        } else {
+        } else if !std::thread::panicking() {
             panic!("Device already dropped")
         }
     }
