@@ -11,7 +11,7 @@ use crate::{
     out_of_host_memory,
     semaphore::Semaphore,
     surface::{PresentMode, SurfaceCapabilities, SurfaceError},
-    Extent2d, OutOfMemory,
+    OutOfMemory,
 };
 use erupt::{
     extensions::{
@@ -110,7 +110,6 @@ struct SwapchainInner {
     images: Vec<SwapchainImageAndSemaphores>,
     acquired_counter: AtomicU32,
     format: Format,
-    extent: Extent2d,
     usage: ImageUsage,
     mode: PresentMode,
     optimal: bool,
@@ -120,7 +119,6 @@ struct SwapchainInner {
 pub struct Swapchain {
     inner: Option<SwapchainInner>,
     retired: VecDeque<SwapchainInner>,
-    retired_offset: u64,
     free_semaphore: Semaphore,
     device: WeakDevice,
     surface: Surface,
@@ -158,7 +156,6 @@ impl Swapchain {
             free_semaphore,
             inner: None,
             retired: VecDeque::new(),
-            retired_offset: 0,
             device: device.downgrade(),
             surface_capabilities,
         })
@@ -170,6 +167,21 @@ impl Swapchain {
         &self.surface_capabilities
     }
 
+    /// Update swapchain images for changed surface.
+    /// Does nothing if not configured.
+    #[tracing::instrument]
+    pub fn update(&mut self) -> Result<(), SurfaceError> {
+        if let Some(inner) = &self.inner {
+            let usage = inner.usage;
+            let format = inner.format;
+            let mode = inner.mode;
+
+            self.configure(usage, format, mode)
+        } else {
+            Ok(())
+        }
+    }
+
     #[tracing::instrument]
     pub fn configure(
         &mut self,
@@ -177,10 +189,7 @@ impl Swapchain {
         format: Format,
         mode: PresentMode,
     ) -> Result<(), SurfaceError> {
-        let device = self
-            .device
-            .upgrade()
-            .ok_or_else(|| SurfaceError::SurfaceLost)?;
+        let device = self.device.upgrade().ok_or(SurfaceError::SurfaceLost)?;
 
         // TODO: Configurable count
         if self.retired.len() > 16 {
@@ -244,7 +253,7 @@ impl Swapchain {
         let sf = formats
             .iter()
             .find(|sf| sf.format == erupt_format)
-            .ok_or_else(|| SurfaceError::FormatUnsupported { format })?;
+            .ok_or(SurfaceError::FormatUnsupported { format })?;
 
         let composite_alpha = {
             let raw = caps.supported_composite_alpha.to_erupt().bits();
@@ -312,7 +321,7 @@ impl Swapchain {
                 .get_swapchain_images_khr(handle, None)
                 .result()
                 .map_err(|err| {
-                    logical.destroy_swapchain_khr(Some(handle), None);
+                    logical.destroy_swapchain_khr(handle, None);
                     surface_error_from_erupt(err)
                 })
         }?;
@@ -326,7 +335,7 @@ impl Swapchain {
             })
             .collect::<Result<Vec<_>, _>>()
             .map_err(|err| unsafe {
-                logical.destroy_swapchain_khr(Some(handle), None);
+                logical.destroy_swapchain_khr(handle, None);
 
                 SurfaceError::OutOfMemory { source: err }
             })?;
@@ -360,7 +369,6 @@ impl Swapchain {
                 })
                 .collect(),
             acquired_counter: AtomicU32::new(0),
-            extent: caps.current_extent,
             format,
             usage,
             mode,
@@ -371,11 +379,8 @@ impl Swapchain {
         Ok(())
     }
 
-    pub fn acquire_image(&mut self, optimal: bool) -> Result<SwapchainImage<'_>, SurfaceError> {
-        let device = self
-            .device
-            .upgrade()
-            .ok_or_else(|| SurfaceError::SurfaceLost)?;
+    pub fn acquire_image(&mut self) -> Result<SwapchainImage<'_>, SurfaceError> {
+        let device = self.device.upgrade().ok_or(SurfaceError::SurfaceLost)?;
 
         assert!(
             device.logical().enabled().khr_swapchain,
@@ -391,17 +396,6 @@ impl Swapchain {
                 return Err(SurfaceError::TooManyAcquired);
             }
 
-            if optimal && !inner.optimal {
-                // If swapchain is not optimal and optimal is requested
-                // swapchain should be recreated.
-                let usage = inner.usage;
-                let format = inner.format;
-                let mode = inner.mode;
-
-                self.configure(usage, format, mode)?;
-                continue;
-            }
-
             // FIXME: Use fences to know that acquire semaphore is unused.
             let wait = &self.free_semaphore;
 
@@ -410,8 +404,8 @@ impl Swapchain {
                     inner.handle,
                     !0, /* wait indefinitely. This is OK as we never try to
                          * acquire more images than there is in swapchain. */
-                    Some(wait.handle()),
-                    None,
+                    wait.handle(),
+                    vk1_0::Fence::null(),
                 )
             };
 
