@@ -54,12 +54,13 @@ fn check_surface_error() {
 #[cfg_attr(feature = "serde-1", derive(serde::Serialize, serde::Deserialize))]
 #[non_exhaustive]
 pub enum RawWindowHandleKind {
-    IOS,
-    MacOS,
+    UiKit,
+    AppKit,
     Xlib,
     Xcb,
     Wayland,
-    Windows,
+    Win32,
+    WinRt,
     Web,
     Android,
     Unknown,
@@ -73,10 +74,10 @@ impl RawWindowHandleKind {
             RawWindowHandle::Android(_) => RawWindowHandleKind::Android,
 
             #[cfg(target_os = "ios")]
-            RawWindowHandle::IOS(_) => RawWindowHandleKind::IOS,
+            RawWindowHandle::UiKit(_) => RawWindowHandleKind::IOS,
 
             #[cfg(target_os = "macos")]
-            RawWindowHandle::MacOS(_) => RawWindowHandleKind::MacOS,
+            RawWindowHandle::AppKit(_) => RawWindowHandleKind::AppKit,
 
             #[cfg(any(
                 target_os = "linux",
@@ -88,7 +89,10 @@ impl RawWindowHandleKind {
             RawWindowHandle::Wayland(_) => RawWindowHandleKind::Wayland,
 
             #[cfg(target_os = "windows")]
-            RawWindowHandle::Windows(_) => RawWindowHandleKind::Windows,
+            RawWindowHandle::Win32(_) => RawWindowHandleKind::Win32,
+
+            #[cfg(target_os = "windows")]
+            RawWindowHandle::WinRt(_) => RawWindowHandleKind::WinRt,
 
             #[cfg(any(
                 target_os = "linux",
